==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/ImagesChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ImagesChangedEventArgsDescription } from "./ImagesChangedEventArgsDescription";
/**
 * @hidden
 */
export let ImagesChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ImagesChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ImagesChangedEventArgsDescriptionMetadata.a == null) {
                ImagesChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ImagesChangedEventArgsDescriptionMetadata.c(ImagesChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(ImagesChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(ImagesChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ImagesChangedEventArgsDescriptionMetadata.b(a);
            a.aa("ImagesChangedEventArgs", () => new ImagesChangedEventArgsDescription());
            a.z("ImagesChangedEventArgs", ImagesChangedEventArgsDescriptionMetadata.a);
        }
    }
    ImagesChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ImagesChangedEventArgsDescriptionMetadata, 'ImagesChangedEventArgsDescriptionMetadata');
    ImagesChangedEventArgsDescriptionMetadata.a = null;
    return ImagesChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ImagesChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ImagesChangedEventArgsDescription } from "./ImagesChangedEventArgsDescription";
/**
 * @hidden
 */
export let ImagesChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ImagesChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ImagesChangedEventArgsDescriptionMetadata.a == null) {
                ImagesChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ImagesChangedEventArgsDescriptionMetadata.c(ImagesChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(ImagesChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(ImagesChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ImagesChangedEventArgsDescriptionMetadata.b(a);
            a.ac("ImagesChangedEventArgs", () => new ImagesChangedEventArgsDescription());
            a.ab("ImagesChangedEventArgs", ImagesChangedEventArgsDescriptionMetadata.a);
        }
    }
    ImagesChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ImagesChangedEventArgsDescriptionMetadata, 'ImagesChangedEventArgsDescriptionMetadata');
    ImagesChangedEventArgsDescriptionMetadata.a = null;
    return ImagesChangedEventArgsDescriptionMetadata;
})();
